pybedtools.scripts.py_ms_example
================================

.. automodule:: pybedtools.scripts.py_ms_example

   
   
   .. rubric:: Functions

   .. autosummary::
   
      main
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      BedTool
   
   

   
   
   